@@ -165,6 +165,8 @@ class Quip:
 
         if "template" in dir(args) and args.template == False and args.name.startswith("ut-"):
             args.template = True
+        else:
+            args.template = False
 
         return args
     
@@ -192,7 +194,7 @@ class Quip:
             if self.args.rename_scripts:
                 self.update_rename_scripts()
             else:
-                self.update_project(self.args.uuid, self.args.new_uuid)
+                self.update_project(self.args.uuid, self.args.new_uuid, new_project=False)
             self.dump_fields(write=True)
         elif action in DELETE_ACTION:
             self.delete_project()
@@ -278,7 +280,7 @@ class Quip:
         self.project_name = self.format_ext_name(project_name)
         self.extension_name = self.format_ext_name(project_name.lower())
         self.template_name = self.titleize(project_name)
-        self.use_keyring = self._global_conf_defaults.get("use_keyring")
+        self.use_keyring = self._global_conf_defaults.get("use_keyring", True)
         logging.debug(f"Project Name: {self.project_name}")
         logging.debug(f"Template Name: {self.template_name}")
 
@@ -301,14 +303,14 @@ class Quip:
         os.makedirs(self.project_name)
         self.uip_init(self.project_name, self.default_template)
         self.update_extension_yaml(self.extension_name)
-        self.update_uip_config(self.project_name)
+        self.update_uip_config(self.project_name, new_project=True)
         self.update_template_json(self.project_name)
 
-    def update_project(self, update_uuid=False, update_new_uuid=False):
+    def update_project(self, update_uuid=False, update_new_uuid=False, new_project=True):
         logging.info(f"Updating extension {self.template_name}")
         if not self.args.template:
-            self.update_extension_yaml(self.extension_name)
-            self.update_uip_config(self.project_name)
+            self.update_extension_yaml(self.extension_name, new_project=new_project)
+            self.update_uip_config(self.project_name, new_project=new_project)
         else:
             self.update_script_config(self.project_name)
         self.update_template_json(self.project_name, update_uuid, update_new_uuid)
@@ -431,7 +433,7 @@ class Quip:
         shutil.rmtree(self.project_name)
     
     def clean_project(self):
-        for folder in ["build", "dist", "temp"]:
+        for folder in ["build", "dist", "temp", "downloads"]:
             folder_path = self.join_path(folder)
         
             if os.path.exists(folder_path):
@@ -445,6 +447,12 @@ class Quip:
                             shutil.rmtree(file_path)
                     except Exception as e:
                         print('Failed to delete %s. Reason: %s' % (file_path, e))
+                try:
+                    shutil.rmtree(folder_path)
+                except Exception as e:
+                    print('Failed to delete %s. Reason: %s' % (folder_path, e))
+        if not self.args.template:
+            self.run_uip("clean")
 
     def clone_project(self, from_project_path, all_files=False, exclude_list=None):
         if not os.path.exists(from_project_path):
@@ -481,7 +489,7 @@ class Quip:
                     shutil.copy2(source_file_path, self.join_path(source_file))
                     logging.info(f"Copying file {source_file}")
         
-        self.update_project(update_uuid=True, update_new_uuid=True)
+        self.update_project(update_uuid=True, update_new_uuid=True, new_project=True)
 
     def bootstrap_project(self):
         # get bootstrap source
@@ -861,7 +869,7 @@ class Quip:
             else:
                 version = datetime.now().strftime("%Y%m%d")
 
-            archive_name = f"unv-tmplt-{project_name}-{version}"
+            archive_name = f"unv-tmplt-{self.format_ext_name(project_name.lower())}-{version}"
             new_archive_file = make_archive(archive_name, "zip", root_dir=tmpdirname)
             logging.info(f"Archive file created. File name is {archive_name}.zip")
             build_folder = self.join_path("build")
@@ -939,6 +947,9 @@ class Quip:
         elif action == "build":
             need_pass = False
             command = f'''uip build -a'''
+        elif action == "clean":
+            need_pass = False
+            command = f'''uip clean'''
 
         if need_pass:
             uac_pass = self.ask_password(uac_url, uac_user)
@@ -976,28 +987,44 @@ class Quip:
                     os.rename(self.join_path("dist", "package_build", filename), new_filepath)
                 cprint(f"File Renamed: {filename} => {new_filename}", "yellow")
 
-    def update_extension_yaml(self, project_name):
+    def update_extension_yaml(self, project_name, new_project=True):
         logging.info("Updating extension.yml file")
         extension_config = self.join_path("src", "extension.yml")
         if os.path.exists(extension_config):
-            with open(extension_config, "w") as f:
-                _extension_config = self._global_conf_extension
-                _extension_config["extension"]["name"] = project_name
-                yaml.dump(_extension_config, f, sort_keys=False)
-                logging.debug("extension.yml file is updated")
+            if new_project:
+                with open(extension_config, "w") as f:
+                    _extension_config = self._global_conf_extension
+                    _extension_config["extension"]["name"] = project_name
+                    yaml.dump(_extension_config, f, sort_keys=False)
+            else:
+                with open(extension_config) as f:
+                    _config = yaml.safe_load(f)
+
+                with open(extension_config, "w") as f:
+                    _config["extension"]["name"] = project_name
+                    yaml.dump(_config, f, sort_keys=False)
+            logging.debug("extension.yml file is updated")
         else:
             logging.error(f"ERROR: extension.yml file is missing! Path= {extension_config}")
             sys.exit(1)
 
-    def update_uip_config(self, project_name):
+    def update_uip_config(self, project_name, new_project=True):
         logging.info("Updating uip.yml file")
         config = self.join_path(".uip", "config", "uip.yml")
         if os.path.exists(config):
-            with open(config, "w") as f:
-                _config = self._global_conf_uip
-                _config["template-name"] = self.template_name
-                yaml.dump(_config, f, sort_keys=False)
-                logging.debug("uip.yml file is updated")
+            if new_project:
+                with open(config, "w") as f:
+                    _config = self._global_conf_uip
+                    _config["template-name"] = self.template_name
+                    yaml.dump(_config, f, sort_keys=False)
+            else:
+                with open(config) as f:
+                    _config = yaml.safe_load(f)
+
+                with open(config, "w") as f:
+                    _config["template-name"] = self.template_name
+                    yaml.dump(_config, f, sort_keys=False)
+            logging.debug("uip.yml file is updated")
         else:
             logging.error(f"ERROR: uip.yml file is missing! Path= {config}")
             sys.exit(1)
